* Configuration                                                                *
* -----------------------------------------------------------------------------*

*-------------------------------- specify your paths here! --------------------*
global dataDir 	"C:\Users\ua\Desktop\MZ" // original data

global dir 		"C:\Users\ua\Desktop\MZ" // folder with the project

global data		"${dir}/data"	
global posted	"${dir}/posted"
global graphs 	"${dir}/graphs"
global tables	"${dir}/tables"



* ------------------------------ Create dyadic data with heterosexual couples -*

* 1. drop children and persons living in facilities
keep if EF35==1 | EF35==2 

* 2. create IDs 
* (source: https://www.gesis.org/missy)
egen hhnr=group (EF1 EF3 EF4)
bysort hhnr: gen pnr_hh=_n 
sort hhnr EF27 EF35
by hhnr EF27: gen pnr_union=_n
lab var hhnr "ID of household"
lab var pnr_hh "ID of person in household"
lab var pnr_union "ID of union in household"

egen pnr_union_max= max (pnr_union), by(hhnr EF27)
drop if pnr_union_max > 2 /* delete unions with more than 2 persons */

sort hhnr EF27 EF46
gen fem_union=0
gen male_union=0
by hhnr EF27: replace fem_union=1 if EF46==2 & EF46[_n-1]==1 & pnr_union_max==2
by hhnr EF27: replace male_union=1 if EF46==1 & EF46[_n+1]==2 & pnr_union_max==2


gen flag=1 if EF35==1 & fem_union==1 
egen flag_union=max(flag) ,by(hhnr EF27)
keep if (male_union==1 | fem_union==1) & flag_union !=1 /*drop erroneous cases*/
drop flag flag_union


* ------------------------------ create new variables -------------------------*


* 1. age
gsort +hhnr  +EF27  +EF35 

gen age_m = EF44[_n-1] if EF46==2
replace age_m = EF44 if EF46==1 
label variable age_m "man's age" 

gen age_f = EF44[_n+1] if EF46==1 
replace age_f = EF44 if EF46==2
label variable age_f "woman's age" 



* 2. CASMIN
* (source: http://www.gesis.org/missy/)

do CASMIN.do

* 2.1 in three categories
generate cas3 = 1 if (casa11 >= 0 & casa11 < 3)
replace cas3 = 2 if (casa11 >=3 & casa11 < 7) 
replace cas3 = 3 if (casa11==7 | casa11==8) 
replace cas3 = . if (casa11==9 | casa11==99) 

label variable cas3 "CASMIN" 
label define cas3 1 "low" 2 "medium" 3 "high" 
label values cas3 cas3 

* 2.2 in three categories by sex
gsort +hhnr +EF27 +EF35

gen cas_m3 = cas3[_n-1] if EF46==2
replace cas_m3 = cas3 if EF46==1 
label variable cas_m3 "man's CASMIN (3)" 
label values cas_m3 cas3 

gen cas_f3 = cas3[_n+1] if EF46==1
replace cas_f3 = cas3 if EF46==2 
label variable cas_f3 "woman's CASMIN (3)" 
label values cas_f3 cas3 

* 2.3 educational constellation
generate cas_educ_const_x = 1 if cas_f3==1 & cas_m3==1
replace cas_educ_const_x = 2 if cas_f3==1 & cas_m3==2 
replace cas_educ_const_x = 3 if cas_f3==1 & cas_m3==3
replace cas_educ_const_x = 4 if cas_f3==2 & cas_m3==1
replace cas_educ_const_x = 5 if cas_f3==2 & cas_m3==2 
replace cas_educ_const_x = 6 if cas_f3==2 & cas_m3==3
replace cas_educ_const_x = 7 if cas_f3==3 & cas_m3==1
replace cas_educ_const_x = 8 if cas_f3==3 & cas_m3==2 
replace cas_educ_const_x = 9 if cas_f3==3 & cas_m3==3

label variable cas_educ_const_x "educational composition (CASMIN)"
label define cas_educ_const_x 	1 "low/low" ///
							2 "low/medium" ///
							3 "low/high" ///
							4 "medium/low" /// 
							5 "medium/medium" ///
							6 "medium/high" ///
							7 "high/low" /// 
							8 "high/medium" /// 
							9 "high/high" 
label values cas_educ_const_x cas_educ_const_x 

* 2.4. educational constellation (5 groups)
recode cas_educ_const_x (2 3 6 = 1 "man>woman") (4 7 8 = 2 "woman>man") /// 
(1 = 3 "homogamous low") (5 = 4 "homogamous medium") /// 
(9 = 5 "homogamous high"), gen(cas_educ_const_5)
label variable cas_educ_const_5 "educational composition (5) (CASMIN)"



* 3. ISCED
* (source: http://www.gesis.org/missy/)

do ISCED.do

* 3.1 in three categories
generate isced3 = 1 if (isced97 >= 1 & isced97 <= 4)
replace isced3 = 2 if (isced97 >=5 & isced97 <= 7) 
replace isced3 = 3 if (isced97>=8 & isced97<=10) 
replace isced3 = . if (isced97==99 | isced97==999) 

label variable isced3 "ISCED" 
label define isced3 1 "low" 2 "medium" 3 "high" , replace
label values isced3 isced3 

* 3.2 in three categories by sex
gsort +hhnr +EF27 +EF35

gen isced_m3 = isced3[_n-1] if EF46==2
replace isced_m3 = isced3 if EF46==1 
label variable isced_m3 "man's isced (3)" 
label values isced_m3 isced3 

gen isced_f3 = isced3[_n+1] if EF46==1
replace isced_f3 = isced3 if EF46==2 
label variable isced_f3 "woman's isced (3)" 
label values isced_f3 isced3 

* 3.3 educational constellation
generate isced_educ_const_x = 1 if isced_f3==1 & isced_m3==1
replace isced_educ_const_x = 2 if isced_f3==1 & isced_m3==2 
replace isced_educ_const_x = 3 if isced_f3==1 & isced_m3==3
replace isced_educ_const_x = 4 if isced_f3==2 & isced_m3==1
replace isced_educ_const_x = 5 if isced_f3==2 & isced_m3==2 
replace isced_educ_const_x = 6 if isced_f3==2 & isced_m3==3
replace isced_educ_const_x = 7 if isced_f3==3 & isced_m3==1
replace isced_educ_const_x = 8 if isced_f3==3 & isced_m3==2 
replace isced_educ_const_x = 9 if isced_f3==3 & isced_m3==3

label variable isced_educ_const_x "educational composition (ISCED)"
label define isced_educ_const_x 	1 "low/low" ///
							2 "low/medium" ///
							3 "low/high" ///
							4 "medium/low" /// 
							5 "medium/medium" ///
							6 "medium/high" ///
							7 "high/low" /// 
							8 "high/medium" /// 
							9 "high/high" 
label values isced_educ_const_x isced_educ_const_x 

* 3.4 educational constellation (5 groups)
recode isced_educ_const_x (2 3 6 = 1 "man>woman") (4 7 8 = 2 "woman>man") /// 
(1 = 3 "homogamous low") (5 = 4 "homogamous medium") /// 
(9 = 5 "homogamous high"), gen(isced_educ_const_5)
label variable isced_educ_const_5 "educational composition (5) (ISCED)"



* 4. weekly working hours
recode EF131 /// 
(56 = 56.5) ///
(58 = 58.5) ///
(62 = 61.5) ///
(63 = 63.5) ///
(66 = 66.5) ///
(75 = 73) ///
(78 = 77.5) ///
(84 = 82.5) ///
(85 = 87) /// 
(97 = 94) ///
(99 = -99), gen(EF131rec) /* recode to class median */

generate wh = EF131rec if EF85== -5 & EF134 >=1 
replace wh = EF131rec if EF134==0 & (EF85== 1 | EF85==4 | EF85==5 ///
	| EF85==6 | EF85==7 | EF85==8 | EF85==9 | EF85==10 | EF85==11) 
replace wh = 0 if EF134==0 & (EF85==2 | EF85==3) 
replace wh = 0 if EF134==0 & EF85 ==-5 
replace wh = 0 if EF85== -5 & EF134== -2

label variable wh "normal weekly working hours"
replace wh = EF134 if wh==. /* errouneaus data */


* 4.1 Dummy parental leave
generate pl = 1 if EF85==3 & wh==0 
replace pl = 0 if pl==.
label variable pl "parental leave (0 working time)" 

* 4.2 Dummy maternity leave
generate ml = 1 if EF85==2 
replace ml = 0 if ml==.
label variable ml "maternity leave" 

* 4.3 weekly working hours by sex
gsort +hhnr +EF27 +EF35

gen wh_m = wh[_n-1] if EF46==2
replace wh_m  = wh  if EF46==1 
label variable wh_m  "man's normal weekly working hours" 

gen wh_f = wh[_n+1] if EF46==1
replace wh_f  = wh  if EF46==2
label variable wh_f  "woman's normal weekly working hours" 

* 4.4 truncation to a max. of 60 hours per week
generate wh_mt = wh_m if wh_m <= 60 
replace wh_mt = 60 if wh_m > 60 
label variable wh_mt "man's normal weekly working hours (trunc.)" 

generate wh_ft = wh_f if wh_f <= 60 
replace wh_ft = 60 if wh_f > 60 
label variable wh_ft "woman's normal weekly working hours (trunc.)" 

* 4.5 sum in couple
generate wh_sum = wh_m + wh_f 
label variable wh_sum "joint weekly working hours"

generate wh_sumt = wh_mt + wh_ft 
label variable wh_sumt "joint weekly working hours (trunc.)"

* 4.6 woman's share of weekly working hours 
generate whshare_f = wh_f / wh_sum 
label variable whshare_f "woman's share of weekly working hours"

generate whshare_ft = wh_ft / wh_sumt
label variable whshare_ft "woman's share of weekly working hours (trunc.)"



* 5. age of youngest child in household
recode EF803 (-5=0 "no children") (0=1 "< 1 year") (1/2=2 "1-2 years" ) ///
	(3/5=3 "3-5 years") (6/9=4 "6-9 years") (10/17=5 "10-17 years") ///
	(18/69=6 "> 17 years"), gen(age_kid6)
label variable age_kid6 "age of the youngest child"

recode age_kid6 (0=0 "no children") (1 = 1 "< 1 years") (2=2 "1-2 years") ///
	(3=3 "3-5 years") (4=4 "6-9 years") (5 6 =5 "> 10 years"),gen (age_kid5)
label variable age_kid5 "age of the youngest child" 



* 6. Dummy: married/not-married
generate married = 1 if EF49==2 
replace married = 0 if married==.

label variable married "married" 



* 7. region in Germany (East with Berlin/West without Berlin) 
generate regio = 0 if EF1 >= 1 & EF1 <= 10 
replace regio = 1 if EF1 >=11 & EF1 <= 16 

label variable regio "region" 
label define regio 0 "West-Germany" 1 "East-Germany" 
label variable regio regio



* ------------------------------ reduce to dyadic file ------------------------*

* 1. reduce to data from persons between ages 18 and 55 
gsort +hhnr +EF27 +EF35

generate no_age = 1 if  age_f < 18 | age_f > 55 | age_m < 18 | age_m > 55
replace no_age = 0 if no_age==.
drop if no_age==1 


* 2. reduce to data from persons not retired
gsort +hhnr +EF27 +EF35

gen rent_m = 1 if EF46==1 & EF413==3 
replace rent_m = 0 if rent_m==.
replace rent_m = rent_m[_n-1]  if EF46==2
label variable rent_m "man retired" 

gen rent_f = 1 if EF46==2 & EF413==3 
replace rent_f = 0 if rent_f==.
replace rent_f = rent_f[_n+1]  if EF46==1
label variable rent_f "woman retired" 

drop if rent_m==1 | rent_f==1 

* 3. drop mother's in maternity leave
* drop if ml==1

* 4. drop men in data
drop if EF46==1


*------------------------------------------------------------------------------*
*  Save to folder "posted"                                                     *
*------------------------------------------------------------------------------*

save "${dir}/posted/data", replace




