*-----------------------------------------------------------------------------*
* Configuration                                                               *
* ----------------------------------------------------------------------------*

*-------------------------------- specify your paths here! -------------------*


global dataDir 	"C:\Users\ua\Desktop\MZ" // original data

global dir 		"C:\Users\ua\Desktop\MZ" // folder with the project

global data		"${dir}/data"	
global posted	"${dir}/posted"
global graphs 	"${dir}/graphs"
global tables	"${dir}/tables"


use "${posted}/data", clear


*-----------------------------------------------------------------------------*
* Table A1: Descriptives of the final sample		                          *
*-----------------------------------------------------------------------------*

preserve
/* drop cases without data for education or female share of working hours */ 
keep if cas_educ_const_x!= . & whshare_ft!=. 
summarize  wh_ft wh_mt wh_sumt whshare_ft age_f age_m 
tab1 cas_m3 cas_f3 age_kid6 married
bysort regio: summarize  wh_ft wh_mt wh_sumt whshare_ft age_f age_m 
bysort regio: tab1 cas_m3 cas_f3 age_kid6 married
restore


*-----------------------------------------------------------------------------*
* Table A2: General Linear Models for women’s share of weekly working hours   *
* (by region) – educational composition in 9 categories		                  *
*-----------------------------------------------------------------------------*

quietly: glm whshare_ft ib(last).cas_educ_const_x c.wh_sumt i.age_kid5 ///
	c.age_f c.age_m i.married if regio==0, /// 
	link(logit) family(binomial) robust nolog omitted baselevel 
eststo A2west 
quietly: margins,  atmeans  at( cas_educ_const_x=(1 2 3 4 5 6 7 8 9)) post
eststo A2west_pred

quietly: glm whshare_ft ib(last).cas_educ_const_x c.wh_sumt i.age_kid5 ///
	c.age_f c.age_m i.married if regio==1, /// 
	link(logit) family(binomial) robust nolog omitted baselevel 
eststo A2east
quietly: margins,  atmeans  at( cas_educ_const_x=(1 2 3 4 5 6 7 8 9)) post
eststo A2east_pred

quietly: glm whshare_ft ib(last).cas_educ_const_x c.wh_sumt i.age_kid5 ///
	c.age_f c.age_m i.married i.regio, /// 
	link(logit) family(binomial) robust nolog omitted baselevel 
eststo A2
quietly: margins,  atmeans  at( cas_educ_const_x=(1 2 3 4 5 6 7 8 9)) post
eststo A2_pred

esttab A2west A2east A2 using "$tables\Table A2"


*-----------------------------------------------------------------------------*
* Figure 1: Adjusted predictions for women’s share of weekly working hours,   *
* by relative education and region		                  					  *
*-----------------------------------------------------------------------------*

coefplot (A2west_pred, label(West-Germany) lcolor(black) lwidth(thin) ///
	msymbol(O) msize(1.2) mcolor(black) ciopts(lcolor(black) lwidth(vthin)) offset(-.1))  ///
	(A2east_pred, label(East-Germany) lcolor(black) lwidth(thin) ///
	msymbol(S) msize(1.1) mcolor(black) ciopts(lcolor(black) lwidth(vthin)) offset(.1)) ///
	(A2_pred, lcolor(black) lwidth(thin) msymbol(T) msize(1.2) mcolor(black) ///
	ciopts(lcolor(black) lwidth(vthin)) label(Germany)), ///
	vertical  format(%9.3g) ///
	title("", size(small) color(black))  ///
	xlabel(1 `"" ""low""low""' 2 `"" ""low""medium""' 3 `"" ""low""high""' ///
	4 `"" ""medium""low""' 5 `"" ""medium""medium""' 6 `"" ""medium""high""' /// 
	7 `"" ""high""low""' 8 `"" ""high""medium""' 9 `"" ""high""high""' , ///
	noticks labsize(vsmall)) xlabel(, ang(20) ) ///
	ytitle("Women's share of weekly working hours", size(small)) ///
	xtitle("Educational composition (woman/man)" , ///
	size(small)) xtitle("Educational composition (woman/man)", margin(medium)) ///
	ylabel(, labsize(vsmall) angle(0))  ///
	graphregion(color(white))  legend(position(10) ring(0) col(1) ///
	size(*0.8) symysize(*0.7) symxsize(*.9) lwidth(thin) keygap(*.5) colgap(*0.8)  ) 

graph export "${graphs}\Figure 1" ,as(tif) 

*-----------------------------------------------------------------------------*
* Table A3: Descriptives of woman’s share of working hours, 				  *
* by presence and age of the youngest child in the household and region       *
*-----------------------------------------------------------------------------*

preserve
/* drop cases without data for education or female share of wokring hours */ 
keep if cas_educ_const_x!= . & whshare_ft!=. 
forval i = 0/5 {
	bysort regio: summarize whshare_ft  if age_kid5==`i'
	summarize whshare_ft  if age_kid5==`i'
}
restore


*-----------------------------------------------------------------------------*
* Table A4: General Linear Models for women’s share of weekly working hours	  *
* (by region) – educational composition in 5 categories						  *
*-----------------------------------------------------------------------------*
  
glm whshare_ft ib(last).cas_educ_const_5 c.wh_sumt i.age_kid5 ///
	c.age_f c.age_m i.married if regio==0, /// 
	link(logit) family(binomial) robust nolog omitted baselevel 
eststo A4west

glm whshare_ft ib(last).cas_educ_const_5 c.wh_sumt i.age_kid5 ///
	c.age_f c.age_m i.married if regio==1, /// 
	link(logit) family(binomial) robust nolog omitted baselevel 
eststo A4east

glm whshare_ft ib(last).cas_educ_const_5 c.wh_sumt i.age_kid5 ///
	c.age_f c.age_m i.married i.regio, /// 
	link(logit) family(binomial) robust nolog omitted baselevel 
eststo A4

esttab A4west A4east A4 using "$tables\Table A4"


*-----------------------------------------------------------------------------*
* Table A5: General Linear Models for women’s share of weekly working hours   *
* (by region) – including interaction terms between educational composition   *
* (5 cat.) and presence/age of the youngest child 							  *
*-----------------------------------------------------------------------------*

glm whshare_ft ib(last).cas_educ_const_5 c.wh_sumt i.age_kid5 ///
	c.age_f c.age_m i.married cas_educ_const_5##age_kid5 if regio==0, /// 
	link(logit) family(binomial) robust nolog omitted baselevel 
eststo A5west

eststo: glm whshare_ft ib(last).cas_educ_const_5 c.wh_sumt i.age_kid5 ///
	c.age_f c.age_m i.married cas_educ_const_5##age_kid5 if regio==1, /// 
	link(logit) family(binomial) robust nolog omitted baselevel 
eststo A5east

eststo: glm whshare_ft ib(last).cas_educ_const_5 c.wh_sumt i.age_kid5 ///
	c.age_f c.age_m i.married cas_educ_const_5##age_kid5 i.regio, /// 
	link(logit) family(binomial) robust nolog omitted baselevel 
eststo A5

esttab A5west A5east A5 using "$tables\Table A5"


*-----------------------------------------------------------------------------*
* Figure 2: Adjusted predictions for women’s proportion of weekly working     *
* hours, by relative education, presence of children/age of the youngest child* 
* and region 							  									  *
*-----------------------------------------------------------------------------*

* West 
foreach num of numlist 1/5 {
	glm whshare_ft i.cas_educ_const_5##i.age_kid5 ///
                 c.wh_sumt c.age_f c.age_m i.married if regio==0, ///
                link(logit) family(binomial) robust nolog omitted baselevel
margins age_kid5, atmeans at(cas_educ_const_5=(`num')) post
eststo Fig2west_`num'   
}
coefplot (Fig2west_1, label(man>woman) recast(connected) lpattern(solid) ///
	lcolor(black) lwidth(thin) msize(small) msymbol(O) mcolor(black) ///
	ciopts(lcolor(black) lwidth(thin)) offset(-.2))  ///
	(Fig2west_2, label(woman>man)  recast(connected) lpattern(shortdash) ///
	lcolor(black) lwidth(thin) msize(small) msymbol(D) mcolor(black) ///
	ciopts(lcolor(black) lwidth(thin)) offset(-.1)) ///
	(Fig2west_3, label(homogamous low) recast(connected) lpattern(dash)  ///
	lcolor(black) lwidth(thin) msize(small) msymbol(T) mcolor(black) ///
	ciopts(lcolor(black) lwidth(thin))) /// 
	(Fig2west_4, label(homogamous medium) recast(connected) ///
	lpattern(longdash)  lcolor(black) lwidth(thin) msize(small) ///
	msymbol(S) mcolor(black) ciopts(lcolor(black) lwidth(thin)) offset(.1)) ///
    (Fig2west_5, label(homogamous high) recast(connected) lpattern(dot) ///
	lcolor(black) lwidth(thin) msize(small) msymbol(X) mcolor(black) ///
	ciopts(lcolor(black) lwidth(thin)) offset(.2)), ///
	vertical  format(%9.3g) ///
	title("West", size(small) color(black)) ///
	xlabel(1 "No" 2 "<1 yr" 3 "1-2 yrs" 4 "3-5 yrs" 5 "6-9 yrs" 6 ">9 yrs", ///
	noticks labsize(vsmall)) ///
	ytitle("Women's share of weekly working hours", size(small)) ///
	ylabel(, labsize(vsmall) angle(0))  graphregion(color(white))  ///
	legend(position(12) ring(0) col(1) size(vsmall) symysize(*0.7) ///
	symxsize(*.9) lwidth(thin) keygap(*.5) colgap(*0.8) )  
graph save Graph "${graphs}\Figure 2 West", replace

*East 
foreach num of numlist 1/5 {
	glm whshare_ft i.cas_educ_const_5##i.age_kid5 ///
                 c.wh_sumt c.age_f c.age_m i.married if regio==1, ///
                link(logit) family(binomial) robust nolog omitted baselevel
margins age_kid5, atmeans at(cas_educ_const_5=(`num')) post
eststo Fig2east_`num'   
}
coefplot (Fig2east_1, label(man>woman) recast(connected) lpattern(solid) ///
	lcolor(black) lwidth(thin) msize(small) msymbol(O) mcolor(black) ///
	ciopts(lcolor(black) lwidth(thin)) offset(-.2))  ///
	(Fig2east_2, label(woman>man)  recast(connected) lpattern(shortdash) ///
	lcolor(black) lwidth(thin) msize(small) msymbol(D) mcolor(black) ///
	ciopts(lcolor(black) lwidth(thin)) offset(-.1)) ///
	(Fig2east_3, label(homogamous low) recast(connected) lpattern(dash)  ///
	lcolor(black) lwidth(thin) msize(small) msymbol(T) mcolor(black) ///
	ciopts(lcolor(black) lwidth(thin))) /// 
	(Fig2east_4, label(homogamous medium) recast(connected) ///
	lpattern(longdash)  lcolor(black) lwidth(thin) msize(small) ///
	msymbol(S) mcolor(black) ciopts(lcolor(black) lwidth(thin)) offset(.1)) ///
    (Fig2east_5, label(homogamous high) recast(connected) lpattern(dot) ///
	lcolor(black) lwidth(thin) msize(small) msymbol(X) mcolor(black) ///
	ciopts(lcolor(black) lwidth(thin)) offset(.2)), ///
	vertical  format(%9.3g) ///
	title("east", size(small) color(black)) ///
	xlabel(1 "No" 2 "<1 yr" 3 "1-2 yrs" 4 "3-5 yrs" 5 "6-9 yrs" 6 ">9 yrs", ///
	noticks labsize(vsmall)) ///
	ytitle("Women's share of weekly working hours", size(small)) ///
	ylabel(, labsize(vsmall) angle(0))  graphregion(color(white))  ///
	legend(position(12) ring(0) col(1) size(vsmall) symysize(*0.7) ///
	symxsize(*.9) lwidth(thin) keygap(*.5) colgap(*0.8) )  
graph save Graph "${graphs}\Figure 2 East", replace
 
graph combine "${graphs}\Figure 2 West" "${graphs}\Figure 2 East", ycommon
graph export "${graphs}\Figure 2", as(tif) replace








*-----------------------------------------------------------------------------*
* ROBUSTNESS CHECKS                                 						  *
*-----------------------------------------------------------------------------*

*******************************************************************************
* 1. with number of children
glm whshare_ft ib(last).cas_educ_const_x c.wh_sumt i.age_kid5 c.age_f c.age_m i.married ///
i.regio EF669, link(logit) family(binomial) robust nolog omitted baselevel 

margins,  atmeans  at(cas_educ_const_x=(1 2 3 4 5 6 7 8 9))
marginsplot, xlabel(, labsize(vsmall)) recast(scatter) xla(, ang(30)) ///
	xtitle("") ytitle("Women's share of weekly working hours") ///
	ytitle(,size(small))  ylabel(, labsize(vsmall)) ///
	ylabel(,angle(0)) legend(pos(6) row(1)) legend(width(135)) ///
	legend(symxsize(4)) legend(keygap(1)) legend(size(vsmall)) /// 
	legend(keygap(*0.7))  title("")

*******************************************************************************
* 2. as OLS-model 
regress whshare_ft ib(last).cas_educ_const_5 wh_sumt i.age_kid5 age_f age_m ///
	i.married i.regio, omitted baselevel 
	eststo OLS
esttab OLS using "$tables\OLS" 

*******************************************************************************
* 3. as Tobit-model 
tobit whshare_ft ib(last).cas_educ_const_5 wh_sumt i.age_kid5 age_f age_m ///
	i.married i.regio, ll(0) ul(1) omitted baselevel 
eststo Tobit
esttab Tobit using "$tables\Tobit" 

/* *******************************************************************************	
* 4. Logit and GLM 
* without interaction effects (mit MS) 
logit new_f ib(last).cas_educ_const_5 c.wh_sumt i.age_kid5 c.age_f c.age_m /// 
	i.married i.regio i.MS, omitted baselevel
		
glm whshare_ft ib(last).cas_educ_const_5 wh_sumt i.age_kid5 age_f age_m i.married ///
	i.regio if whshare_ft > 0 , link(logit) family(binomial) robust nolog ///
	omitted baselevel
 
* with interaction effects  
logit new_f ib(last).cas_educ_const_5 c.wh_sumt i.age_kid5 c.age_f c.age_m /// 
	i.married i.regio i.MS bildkonst_5##age_kid5, omitted baselevel
 
glm whshare_ft ib(last).cas_educ_const_5 wh_sumt i.age_kid5 age_f age_m i.married ///
	i.regio bildkonst_5##age_kid5 , link(logit) family(binomial) ///
	robust nolog omitted baselevel

margins cas_educ_const_5, atmeans  at( age_kid5=(0 1 2 3 4 5)) 
marginsplot, xlabel(, labsize(vsmall)) xla(, ang(30)) xtitle("") ytitle("Women's share of weekly working hours") ytitle(,size(small))  ylabel(, labsize(vsmall)) ///
	ylabel(,angle(0)) legend(pos(6) row(1)) legend(width(135)) legend(symxsize(4)) legend(keygap(1)) legend(size(vsmall)) /// 
	legend(keygap(*0.7))  title("Margins at means")  */

*******************************************************************************	
/*
* 5. as ZOIB 

* ohne Interaktion (mit MS) 
zoib whshare_ft ib(last).cas_educ_const_5 c.wh_sumt i.age_kid5 c.age_f ///
	c.age_m i.married i.regio, ///
	zeroinflate (ib(last).cas_educ_const_5 c.wh_sumt i.age_kid5 c.age_f ///
	c.age_m i.married i.regio i.MS )  
eststo ZOIB1
esttab ZOIB1 using "$tables\ZOIB without interaction" 

* mit Interaktion (mit MS) 
zoib whshare_ft ib(last).cas_educ_const_5 c.wh_sumt i.age_kid5 c.age_f ///
	c.age_m i.married i.regio bildkonst_5##age_kid5, ///
	zeroinflate (ib(last).cas_educ_const_5 c.wh_sumt i.age_kid5 ///
	c.age_f c.age_m i.married i.regio i.MS bildkonst_5##age_kid5)  
eststo ZOIB2
esttab ZOIB2 using "$tables\ZOIB wit interaction"  */

*******************************************************************************	
* 6. with an indicator for the family life cycle 
* (source: Steiber et al. 2016) 
* childless phase: no children in household and <40 years old
 
generate fam_cycle = 0 if age_kid5==0 & age_f < 40 
replace fam_cycle = 1 if age_kid5==1
replace fam_cycle = 2 if age_kid5==2 
replace fam_cycle = 3 if age_kid5==3 
replace fam_cycle = 4 if age_kid5==4
replace fam_cycle = 5 if age_kid5==5 
replace fam_cycle = 6 if age_kid5==0 & age_f > 39 
 
glm whshare_ft ib(last).cas_educ_const_5 wh_sumt i.fam_cycle age_f age_m ///
	i.married i.regio cas_educ_const_5##fam_cycle , link(logit) family(binomial) ///
	robust nolog omitted baselevel
eststo flc
esttab flc using "$tables\family life cycle" 

margins cas_educ_const_5, atmeans  at( fam_cycle =(0 1 2 3 4 5 6)) post 
marginsplot, xlabel(, labsize(vsmall)) xla(, ang(30))   xtitle("") ///
	ytitle("Women's share of weekly working hours") ytitle(,size(small)) ///
	ylabel(, labsize(vsmall)) ///
	ylabel(,angle(0)) legend(pos(6) row(1)) legend(width(135)) ///
	legend(symxsize(4)) legend(keygap(1)) legend(size(vsmall)) /// 
	legend(keygap(*0.7))  title("Margins at means")
graph export graph export "${graphs}\family life cycle", as(tif) replace

*******************************************************************************
* 7. without truncation

* without interaction effects
glm whshare_f ib(last).cas_educ_const_x c.wh_sum i.age_kid5 c.age_f c.age_m i.married i.regio, /// 
link(logit) family(binomial) robust nolog omitted baselevel 

margins,  atmeans  at( cas_educ_const_x=(1 2 3 4 5 6 7 8 9))
marginsplot, xlabel(, labsize(vsmall)) recast(scatter) xla(, ang(20) )  /// 
 xtitle("Relative education: women/man") /// 
ytitle("Women's proportion of weekly working hours") ytitle(,size(small))  /// 
ylabel(, labsize(vsmall)) ///
ylabel(,angle(0)) legend(pos(6) row(1) ) legend(width(135)) //// 
legend(symxsize(4)) legend(keygap(1)) legend(size(vsmall)) /// 
legend(keygap(*0.7))  title("") ///
xtitle (,size(small))
graph export "${graphs}\without truncation", as(tif) replace
 
* with interaction effects
foreach num of numlist 1/5 {
	glm whshare_f i.cas_educ_const_5##i.age_kid5 ///
    c.wh_sum c.age_f c.age_m i.married i.regio, ///
    link(logit) family(binomial) robust nolog omitted baselevel
	margins age_kid5, atmeans at(bildkonst_5=(`num')) post
	eststo m_`num'   
}
coefplot (m_1, label(man>woman) recast(connected) lpattern(solid) ///
	lcolor(black) lwidth(thin) msize(small) msymbol(O) mcolor(black) ///
	ciopts(lcolor(black) lwidth(thin)) offset(-.2))  ///
         (m_2, label(woman>man)  recast(connected) lpattern(shortdash) lcolor(black) lwidth(thin) msize(small) msymbol(D) mcolor(black) ciopts(lcolor(black) lwidth(thin)) offset(-.1)) ///
         (m_3, label(homogamous low) recast(connected) lpattern(dash) lcolor(black) lwidth(thin) msize(small) msymbol(T) mcolor(black) ciopts(lcolor(black) lwidth(thin))) /// 
         (m_4, label(homogamous medium) recast(connected)  lpattern(longdash)  lcolor(black) lwidth(thin) msize(small) msymbol(S) mcolor(black) ciopts(lcolor(black) lwidth(thin)) offset(.1)) ///
         (m_5, label(homogamous high) recast(connected) lpattern(dot) lcolor(black) lwidth(thin) msize(small) msymbol(X) mcolor(black) ciopts(lcolor(black) lwidth(thin)) offset(.2)), ///
vertical  format(%9.3g) ///
title("", size(small) color(black)) ///
  xlabel(1 "No children" 2 "< 1 year" 3 "1-2 years" 4 "3-5 years" 5 "6-9 years" 6 "> 9 years", noticks labsize(small)) ///
  ytitle("Women's proportion of weekly working hours", size(small)) ///
  ylabel(, labsize(vsmall) angle(0)) ///
  legend(position(5) ring(0) col(1) size(*0.8) symysize(*0.7) symxsize(*.9) lwidth(thin) keygap(*.5) colgap(*0.8) )
graph export "${graphs}\with interaction without truncation ", as(tif) replace
  
  
******************************************************************************* 
* 8. with alternative educational classification: ISCED 
 
glm whshare_ft ib(last).isced_educ_const_5 c.wh_sumt i.age_kid5 ///
	c.age_f c.age_m i.married isced_educ_const_5##age_kid5 if regio==0, /// 
	link(logit) family(binomial) robust nolog omitted baselevel 
eststo A5west_isced

eststo: glm whshare_ft ib(last).isced_educ_const_5 c.wh_sumt i.age_kid5 ///
	c.age_f c.age_m i.married isced_educ_const_5##age_kid5 if regio==1, /// 
	link(logit) family(binomial) robust nolog omitted baselevel 
eststo A5east_isced

eststo: glm whshare_ft ib(last).isced_educ_const_5 c.wh_sumt i.age_kid5 ///
	c.age_f c.age_m i.married isced_educ_const_5##age_kid5 i.regio, /// 
	link(logit) family(binomial) robust nolog omitted baselevel 
eststo A5_isced

esttab A5west_isced A5east_isced A5_isced using "$tables\Table A5_isced"

