/****************************************************************************
GESIS - Leibniz-Institut fuer Sozialwissenschaften
German Microdata Lab (GML)
Postfach 12 21 55
68072 Mannheim
Tel.: 0621/1246-265 Fax:  0621/1246-100
E-Mail: gml@gesis.org
Version: 29.09.2015
******************************************************************************/

/* STATA-Syntax zur Umsetzung der CASMIN-Bildungsklassifikation mit dem
Mikrozensus 2011

Bei Nutzung dieser Routine bitte wie folgt zitieren:
(hier wird auch die Skalenkonstruktion beschrieben)
Lechert, Y.; Schroedter, J.; Luettinger, P. (2006): Die Umsetzung der
Bildungsskala CASMIN fuer die Volkszaehlung 1970, die Mikrozensus-Zusatzerhebung
1971 und die Mikrozensen 1976-2004. ZUMA-Methodenbericht 2006/12.
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/gesis_reihen/
gesis_methodenberichte/2006/06_12_lechert.pdf

Literaturhinweise, Quellen:
Brauns, H.; Scherer, S.; Steinmann, S., 2003: The CASMIN Educational
Classification in International Comparative Research. S. 196-221 in: 
Hoffmeyer-Zlotnik, J.H.P; Wolf, C. (Hrsg): Advances in Cross-National 
Comparison. An European Working Book for Demographic and 
Socio-Economic Variables. Amsterdam.

Datenbasis: Mikrozensus 2011, Scientific Use File
Datenbeschreibung: http://www.gesis.org/missy/auswahl-datensatz/mikrozensus-2011/ 
                   
Programm: http://www.gesis.org/missy/fileadmin/missy/klassifikationen/Casmin/
Casmin_STATA/mz11_casmin_gml.do

**************************************************************************** */

* Zeitpunktbezogene CASMIN-Klassifikation (MZ2011) (cas11 / casa11)

* Allgemeinbildender Abschluss (schul11)
recode EF310k (-3 -5=0   "[0] entf.") ///
              (6=1       "[1] kein AB") ///    /* Abschluss nach hoechstens 7 Jahren Schulbesuch */
              (9=2       "[2] o.A. zur Art") ///
              (1=3       "[3] HS/VS") ///
              (2 3 7=4   "[4] RS/POS") ///
              (4 5=5     "[5] FHR/ABI"), generate(schul11)
replace schul11=1 if (EF309==8)
label variable schul11 "Allgemeinbildender Abschluss" 

tab schul11
******************************************************************************
* Berufsbildender Abschluss (ber11)
recode EF312k (-3 -5=0             "[0] entf.") ///
              (1 2=3               "[3] Anlernausb. (BVJ)") ///
              (3 4 5 6 7 8 9 10=4  "[4] Ausb./Meist./Techn./Vorber.mittl.Dienst") ///
              (12=5                "[5] Verw.-FH") ///
              (11 13=6             "[6] FH/Berufsakad.") ///
              (14 15=7             "[7] Uni") ///
              (99=1                "[1] o.A. zur Art"), generate(ber11)
replace ber11=2 if (EF311==8)                                       
label variable ber11 "Berufsbildender Abschluss"
label define ber11 2 "[2] kein AB", add modify

tab ber11
******************************************************************************
* Kreuztabelle zur Bildung der CASMIN-Klassifikation

tab schul11 ber11, miss

******************************************************************************
* CASMIN-Klassifikation des GML (ZEITPUNKTBEZOGEN)
generate cas11=99
replace cas11=99  if ((schul11==0 | ber11==0))
replace cas11=0   if (((schul11==0 | schul11==1) & ///
                      (ber11==1 | ber11==2 | ber11==3)) | ///
                      (schul11==1 & ber11==0)) 
replace cas11=1   if ((schul11==2 | schul11==3) & ///
                      (ber11==0 | ber11==1 | ber11==2 | ber11==3))
replace cas11=2  if ((schul11==0 | schul11==1 | ///
                      schul11==2 | schul11==3) & ///
                     (ber11==4 | ber11==5))
replace cas11=3  if (schul11==4 & (ber11==0 | ///
                     ber11==1 | ber11==2 | ber11==3))
replace cas11=4  if (schul11==4 & (ber11==4 | ber11==5))
replace cas11=5  if (schul11==5 & (ber11==0 | ///
                     ber11==1 | ber11==2 | ber11==3))
replace cas11=6  if (schul11==5 & (ber11==4 | ber11==5))
replace cas11=7  if ber11==6
replace cas11=8  if ber11==7
lab variable cas11 "CASMIN-Klassifikation des GML"
label define cas11 0 "[0] 1a (kein Ab.)" ///
                   1 "[1] 1b (HSO)" ///
                   2 "[2] 1c (HSM)" ///
                   3 "[3] 2b (MRO)" ///
                   4 "[4] 2a (MRM)" ///
                   5 "[5] 2c_gen (ABIO)" ///
                   6 "[6] 2c_voc (ABIM)" ///
                   7 "[7] 3a (FH)" ///
                   8 "[8] 3b (UNI)" ///
                  99 "[99] entf./o.A."
label values cas11 cas11
tab cas11, miss

******************************************************************************
* CASMIN-Klassifikation des GML (ZEITPUNKTBEZOGEN) mit Beruecksichtigung
* von Personen in gegenw. Ausbildung
generate casa11=cas11
replace casa11=9 if (EF287>=1 & EF287<=2)
label variable casa11 "CASMIN-Klassifikation des GML in Ausb. separat"
label define casa11 0 "[0] 1a (kein Ab.)" ///
                    1 "[1] 1b (HSO)" ///
                    2 "[2] 1c (HSM)" ///
                    3 "[3] 2b (RSO)" ///
                    4 "[4] 2a (RSM)" ///
                    5 "[5] 2c_gen (ABIO)" ///
                    6 "[6] 2c_voc (ABIM)" ///
                    7 "[7] 3a (FH)" ///
                    8 "[8] 3b (UNI)" ///
                    9 "[9] in Ausbildung" ///
                   99 "[99] entf./o.A."
label values casa11 casa11
tab casa11, miss

* ENDE CASMIN do-file GESIS
******************************************************************************
